@@ -21,6 +21,7 @@ import json
 import socket
 import time
 
+from astropy.time import Time
 from celery import group
 from celery.utils.log import get_task_logger
 from glue.lal import Cache
@@ -34,6 +35,7 @@ from . import gracedb
 from ..import app
 from ..import _version
 from ..jinja import env
+from ..util import closing_figures
 
 
 __author__ = 'Geoffrey Mo <geoffrey.mo@ligo.org>'
@@ -97,6 +99,7 @@ def create_cache(ifo, start, end):
 
 
 @app.task(shared=False)
+@closing_figures()
 def make_omegascan(ifo, t0, durs):
     """Helper function to create a single omegascan image, with
     multiple durations.
@@ -117,6 +120,9 @@ def make_omegascan(ifo, t0, durs):
         bytes of png of the omegascan, or None if no omegascan created.
 
     """
+    # Explicitly use a non-interactive Matplotlib backend.
+    plt.switch_backend('agg')
+
     # Collect data
     longest = max(durs)
     long_start, long_end = t0 - longest, t0 + longest
@@ -164,8 +170,16 @@ def omegascan(t0, graceid):
     """
     durs = app.conf['omegascan_durations']
 
+    # Delay for early warning events (ie queries for times before now)
+    if t0 + max(durs) > Time.now().gps:
+        log.info("Delaying omegascan because %s is in the future",
+                 graceid)
+        waittime = t0 - Time.now().gps + max(durs) + 10
+    else:
+        waittime = max(durs) + 10
+
     group(
-        make_omegascan.s(ifo, t0, durs)
+        make_omegascan.s(ifo, t0, durs).set(countdown=waittime)
         |
         gracedb.upload.s(f"{ifo}_omegascan.png", graceid,
                          f"{ifo} omegascan", tags=['data_quality'])
@@ -395,9 +409,15 @@ def check_vectors(event, graceid, start, end):
         Details of the event, reflecting any labels that were added.
 
     """
+    # Skip early warning events (ie queries for times before now)
+    if start > Time.now().gps:
+        log.info("Skipping detchar checks because %s is in the future",
+                 event['graceid'])
+        return event
+
     # Skip MDC events.
     if event.get('search') == 'MDC':
-        log.info('Skipping state vector checks because %s is an MDC',
+        log.info("Skipping detchar checks because %s is an MDC",
                  event['graceid'])
         return event
 
