@@ -6,6 +6,8 @@ superevents.
 *   Primary logic to respond to low latency triggers contained in
     :meth:`process` function.
 """
+from itertools import filterfalse
+
 from celery.utils.log import get_task_logger
 from ligo.segments import segment, segmentlist
 
@@ -177,7 +179,8 @@ def process(payload):
     if should_publish(event_info):
         gracedb.create_label.delay('ADVREQ', sid)
         if is_complete(event_info):
-            if app.conf['preliminary_alert_timeout']:
+            if app.conf['preliminary_alert_timeout'] \
+                    and 'EARLY_WARNING' not in event_info['labels']:
                 gracedb.create_label.s(FROZEN_LABEL, sid).set(
                     queue='superevent',
                     countdown=app.conf['preliminary_alert_timeout']
@@ -346,8 +349,8 @@ def get_instruments_in_ranking_statistic(event):
 
 @app.task(shared=False)
 def select_preferred_event(events):
-    """Select the preferred event out of a list of events, typically contents
-    of a superevent, based on :meth:`keyfunc`.
+    """Select the preferred event out of a list of G events, typically
+    contents of a superevent, based on :meth:`keyfunc`.
 
     Parameters
     ----------
@@ -355,7 +358,10 @@ def select_preferred_event(events):
         list of event dictionaries
 
     """
-    return max(events, key=keyfunc)
+    # FIXME: Requires robust determination of an External event
+    g_events = list(
+        filterfalse(lambda x: x['graceid'].startswith('E'), events))
+    return max(g_events, key=keyfunc)
 
 
 def is_complete(event):
@@ -412,15 +418,17 @@ def _should_publish(event):
     the publishability criteria as a tuple for later use.
     """
     group = event['group'].lower()
-    trials_factor = app.conf['preliminary_alert_trials_factor'][group]
-    if event.get('search') == 'EarlyWarning':
+    if 'EARLY_WARNING' in event['labels']:
         far_threshold = app.conf['early_warning_alert_far_threshold']
+        trials_factor = app.conf['early_warning_alert_trials_factor']
     else:
         far_threshold = app.conf['preliminary_alert_far_threshold'][group]
+        trials_factor = app.conf['preliminary_alert_trials_factor'][group]
     far = trials_factor * event['far']
     raven_coincidence = ('RAVEN_ALERT' in event['labels'])
 
-    return not event['offline'], (far <= far_threshold or raven_coincidence)
+    return (not event['offline'] and 'INJ' not in event['labels'],
+            far <= far_threshold or raven_coincidence)
 
 
 def keyfunc(event):
