@@ -1,33 +1,35 @@
+from importlib import resources
 from io import BytesIO
 import logging
 from unittest.mock import call, patch
 
+from astropy.time import Time
 from gwpy.timeseries import Bits
 import matplotlib.pyplot as plt
 import numpy as np
-from pkg_resources import resource_filename
 import pytest
 
 from ..import app
 from ..import _version
 from ..tasks import detchar
+from . import data
 
 
 @pytest.fixture
 def llhoft_glob_pass():
     old = app.conf['llhoft_glob']
-    app.conf['llhoft_glob'] = resource_filename(
-        __name__, 'data/llhoft/pass/{detector}/*.gwf')
-    yield
+    with resources.path(data, '') as path:
+        app.conf['llhoft_glob'] = str(path / 'llhoft/pass/{detector}/*.gwf')
+        yield
     app.conf['llhoft_glob'] = old
 
 
 @pytest.fixture
 def llhoft_glob_fail():
     old = app.conf['llhoft_glob']
-    app.conf['llhoft_glob'] = resource_filename(
-        __name__, 'data/llhoft/fail/{detector}/*.gwf')
-    yield
+    with resources.path(data, '') as path:
+        app.conf['llhoft_glob'] = str(path / 'llhoft/fail/{detector}/*.gwf')
+        yield
     app.conf['llhoft_glob'] = old
 
 
@@ -85,8 +87,11 @@ def test_create_cache_old_data(mock_find, llhoft_glob_fail):
     mock_find.assert_called()
 
 
-@patch('gwcelery.tasks.detchar.create_cache', return_value=[resource_filename(
-    __name__, 'data/llhoft/omegascan/scanme.gwf')])
+with resources.path(data, '') as expected_path:
+    expected_path = str(expected_path / 'llhoft/omegascan/scanme.gwf')
+
+
+@patch('gwcelery.tasks.detchar.create_cache', return_value=[expected_path])
 def test_make_omegascan_worked(mock_create_cache, scan_strainname):
     durs = [1, 1, 1]
     t0 = 1126259463
@@ -120,6 +125,14 @@ def test_omegascan(mock_upload, mock_fig):
     )
 
 
+def test_omegascan_skips_ew(caplog):
+    """Test that omegascans are delayed for events in the future."""
+    caplog.set_level(logging.INFO)
+    detchar.omegascan(Time.now().gps + 99, 'S1234')
+    messages = [record.message for record in caplog.records]
+    assert 'Delaying omegascan because S1234 is in the future' in messages  # noqa: E501
+
+
 def test_check_idq(llhoft_glob_pass):
     channel = 'H1:IDQ-PGLITCH_OVL_32_2048'
     start, end = 1216577976, 1216577980
@@ -191,11 +204,20 @@ def test_check_vector_fails_on_empty(mock_statevector, llhoft_glob_pass):
 
 
 def test_check_vectors_skips_mdc(caplog):
-    """Test that state vector checks are skipped for MDC events."""
+    """Test that detchar checks are skipped for MDC events."""
     caplog.set_level(logging.INFO)
     detchar.check_vectors({'search': 'MDC', 'graceid': 'M1234'}, 'S123', 0, 1)
     messages = [record.message for record in caplog.records]
-    assert 'Skipping state vector checks because M1234 is an MDC' in messages
+    assert 'Skipping detchar checks because M1234 is an MDC' in messages
+
+
+def test_check_vectors_skips_ew(caplog):
+    """Test that detchar checks are skipped for events in the future."""
+    caplog.set_level(logging.INFO)
+    detchar.check_vectors({'pipeline': 'gstlal', 'graceid': 'S1234'},
+                          'S123', 99999999999999999, 99999999999999999.5)
+    messages = [record.message for record in caplog.records]
+    assert 'Skipping detchar checks because S1234 is in the future' in messages  # noqa: E501
 
 
 @patch('gwcelery.tasks.detchar.dqr_json', return_value='dqrjson')
